@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-password-manager.c,v 1.7 2005/01/15 20:26:36 jframeau Exp $
+ *  $Id: ephy-password-manager.c,v 1.9 2006/09/13 11:34:13 chpe Exp $
  */
 
 #include "config.h"
@@ -113,7 +113,7 @@ ephy_password_manager_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyPasswordManagerIface),
 			ephy_password_manager_base_init,
