@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-entry.c 6744 2006-12-17 19:07:04Z chpe $
+ *  $Id: ephy-location-entry.c,v 1.82 2006/09/13 21:11:34 jframeau Exp $
  */
 
 #include "config.h"
@@ -107,7 +107,6 @@ static const GtkTargetEntry url_drag_types [] =
 };
 
 static const GdkColor fallback_bg_colour = { 0, 0xf7f7, 0xf7f7, 0xbebe }; /* yellow-ish */
-static const GdkColor fallback_fg_colour = { 0, 0, 0, 0 }; /* black */
 
 static void ephy_location_entry_class_init (EphyLocationEntryClass *klass);
 static void ephy_location_entry_init (EphyLocationEntry *le);
@@ -209,7 +208,8 @@ ephy_location_entry_style_set (GtkWidget *widget,
 	}
 	else
 	{
-		priv->secure_fg_colour = fallback_fg_colour;
+		/* FIXME: fall back to black text maybe? */
+		priv->secure_fg_colour = widget->style->text[GTK_STATE_NORMAL];
 	}
 
 	if (bg_colour != NULL)
@@ -831,6 +831,33 @@ favicon_drag_data_get_cb (GtkWidget *widget,
 		time, entry, each_url_get_data_binder);
 }
 
+static gboolean
+icon_button_press_event_cb (GtkWidget *ebox,
+			    GdkEventButton *event,
+			    EphyLocationEntry *entry)
+{
+	guint state = event->state & gtk_accelerator_get_default_mod_mask ();
+
+	if (event->type == GDK_BUTTON_PRESS && 
+	    event->button == 1 && 
+	    state == 0 /* left */)
+	{
+		GtkWidget *toplevel;
+		EphyLocationEntryPrivate *priv = entry->priv;
+		
+		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (entry));
+        	gtk_window_set_focus (GTK_WINDOW(toplevel),
+                              	      priv->icon_entry->entry);
+
+		gtk_editable_select_region (GTK_EDITABLE (priv->icon_entry->entry), 
+					    0, -1);
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 static gboolean
 lock_button_press_event_cb (GtkWidget *ebox,
 			    GdkEventButton *event,
@@ -871,6 +898,8 @@ ephy_location_entry_construct_contents (EphyLocationEntry *entry)
 	gtk_drag_source_set (priv->icon_ebox, GDK_BUTTON1_MASK,
 			     url_drag_types, G_N_ELEMENTS (url_drag_types),
 			     GDK_ACTION_ASK | GDK_ACTION_COPY | GDK_ACTION_LINK);
+	g_signal_connect (priv->icon_ebox, "button-press-event",
+			  G_CALLBACK (icon_button_press_event_cb), entry);
 
 	gtk_tooltips_set_tip (priv->tips, priv->icon_ebox,
 			      _("Drag and drop this icon to create a link to this page"), NULL);
