@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c 6827 2007-01-17 23:55:39Z diegoe $
+ * $Id: ephy-bookmarks-editor.c,v 1.198 2006/10/15 14:03:37 wbolster Exp $
  */
 
 #include "config.h"
@@ -1363,7 +1363,7 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 		EphyNode *node = selected->data;
 		char name[EPHY_BOOKMARK_ACTION_NAME_BUFFER_SIZE];
 
-		if (node == NULL) return;
+		g_return_if_fail (node != NULL);
 
 		mutable = !ephy_node_get_property_boolean (node, EPHY_NODE_BMK_PROP_IMMUTABLE);
 		
@@ -1871,7 +1871,7 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 	gtk_paned_pack2 (GTK_PANED (hpaned), vbox, TRUE, TRUE);
 	gtk_widget_show (vbox);
 
-	gtk_box_pack_start (GTK_BOX (vbox),
+	gtk_box_pack_start (GTK_BOX (editor->priv->main_vbox),
 			    build_search_box (editor),
 			    FALSE, FALSE, 0);
 	add_focus_monitor (editor, editor->priv->search_entry);
