@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2004 Christian Persch
+ *  Copyright © 2002 Jorn Baayen
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.c,v 1.19 2006/01/18 14:21:11 chpe Exp $
+ *  $Id: ephy-statusbar.c,v 1.23 2006/09/13 11:34:23 chpe Exp $
  */
 
 #include "config.h"
@@ -38,8 +38,6 @@ static void ephy_statusbar_class_init	(EphyStatusbarClass *klass);
 static void ephy_statusbar_init		(EphyStatusbar *t);
 static void ephy_statusbar_finalize	(GObject *object);
 
-static GObjectClass *parent_class = NULL;
-
 #define EPHY_STATUSBAR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_STATUSBAR, EphyStatusbarPrivate))
 
 struct _EphyStatusbarPrivate
@@ -54,6 +52,15 @@ struct _EphyStatusbarPrivate
 	GtkWidget *popups_manager_evbox;
 };
 
+enum
+{
+	LOCK_CLICKED,
+	LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL];
+static GObjectClass *parent_class;
+
 GType
 ephy_statusbar_get_type (void)
 {
@@ -61,7 +68,7 @@ ephy_statusbar_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyStatusbarClass),
 			NULL, /* base_init */
@@ -91,6 +98,17 @@ ephy_statusbar_class_init (EphyStatusbarClass *klass)
 
 	object_class->finalize = ephy_statusbar_finalize;
 
+	signals[LOCK_CLICKED] =
+		g_signal_new
+			("lock-clicked",
+			 EPHY_TYPE_STATUSBAR,
+			 G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+			 G_STRUCT_OFFSET (EphyStatusbarClass, lock_clicked),
+			 NULL, NULL,
+			 g_cclosure_marshal_VOID__VOID,
+			 G_TYPE_NONE,
+			 0);
+
 	g_type_class_add_private (object_class, sizeof (EphyStatusbarPrivate));
 }
 
@@ -126,6 +144,23 @@ create_caret_indicator (EphyStatusbar *statusbar)
 			    FALSE, FALSE, 0);
 }
 
+static gboolean
+padlock_button_press_cb (GtkWidget *ebox,
+                         GdkEventButton *event,
+			 EphyStatusbar *statusbar)
+{
+        if (event->type == GDK_BUTTON_PRESS &&
+	    event->button == 1 /* left */ &&
+	    (event->state & gtk_accelerator_get_default_mod_mask ()) == 0)
+        {
+		g_signal_emit (statusbar, signals[LOCK_CLICKED], 0);
+
+                return TRUE;
+        }
+
+        return FALSE;
+}
+
 static void
 create_statusbar_security_icon (EphyStatusbar *s)
 {
@@ -137,6 +172,10 @@ create_statusbar_security_icon (EphyStatusbar *s)
 	s->priv->security_evbox = gtk_event_box_new ();
 	gtk_event_box_set_visible_window (GTK_EVENT_BOX (s->priv->security_evbox),
 					  FALSE);
+	gtk_widget_add_events (s->priv->security_evbox, GDK_BUTTON_PRESS_MASK);
+	g_signal_connect (s->priv->security_evbox, "button-press-event",
+			  G_CALLBACK (padlock_button_press_cb), s);
+
 	gtk_container_add (GTK_CONTAINER (s->security_frame),
 			   GTK_WIDGET (s->priv->security_evbox));
 	gtk_container_add (GTK_CONTAINER (s->priv->security_evbox),
@@ -221,8 +260,7 @@ ephy_statusbar_init (EphyStatusbar *t)
 	t->priv = EPHY_STATUSBAR_GET_PRIVATE (t);
 
 	t->tooltips = gtk_tooltips_new ();
-	g_object_ref (G_OBJECT (t->tooltips));
-	gtk_object_sink (GTK_OBJECT (t->tooltips));
+	g_object_ref_sink (t->tooltips);
 
 	t->priv->icon_container = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (t), t->priv->icon_container, FALSE, FALSE, 0);
